==> spark-operator-chart-1.1.4.tar.gz: spark-operator/docs/who-is-using.md <==
## Who Is Using the Kubernetes Operator for Apache Spark?

| Organization | Contact (GitHub User Name) | Environment | Description of Use |
| ------------- | ------------- | ------------- | ------------- |
| [Caicloud](https://intl.caicloud.io/) | @gaocegege | Production | Cloud-Native AI Platform |
| Microsoft (MileIQ) | @dharmeshkakadia | Production | AI & Analytics |
| Lightbend | @yuchaoran2011 | Production | Data Infrastructure & Operations |
| StackTome | @emiliauskas-fuzzy | Production | Data pipelines |
| Salesforce | @khogeland | Production | Data transformation |
| Bringg | @EladDolev | Production | ML & Analytics Data Platform |
| CERN | @mrow4a | Evaluation | Data Mining & Analytics |
| Lyft | @kumare3 | Evaluation | ML & Data Infrastructure |
| MapR Technologies | @sarjeet2013 | Evaluation | ML/AI & Analytics Data Platform |
| Uber | @chenqin | Evaluation | Spark / ML |
| HashmapInc | @prem0132 | Evaluation | Analytics Data Platform |
| Tencent | @runzhliu | Evaluation | ML Analytics Platform |
| Exacaster | @minutis | Evaluation | Data pipelines |
| Riskified | @henbh | Evaluation | Analytics Data Platform |
| CloudZone | @iftachsc | Evaluation | Big Data Analytics Consultancy |
| Cyren | @avnerl | Evaluation | Data pipelines |
| Shell (Agile Hub) | @TomLous | Production | Data pipelines |
| Nielsen Identity Engine | @roitvt | Evaluation | Data pipelines |
| [Data Mechanics](https://www.datamechanics.co)  | @jrj-d | Production | Managed Spark Platform |
| [PUBG](https://careers.pubg.com/#/en/) | @jacobhjkim | Production | ML & Data Infrastructure |
| [Beeline](https://beeline.ru) | @spestua | Evaluation | ML & Data Infrastructure |
| [Stitch Fix](https://multithreaded.stitchfix.com/) | @nssalian | Evaluation | Data pipelines |
| [Typeform](https://typeform.com/) | @afranzi | Production | Data & ML pipelines |
| incrmntal(https://incrmntal.com/) | @scravy | Production | ML & Data Infrastructure |
| [CloudPhysics](https://www.cloudphysics.com) | @jkleckner | Production | ML/AI & Analytics |
| [MongoDB](https://www.mongodb.com) | @chickenpopcorn | Production | Data Infrastructure |
| [MavenCode](https://www.mavencode.com) | @charlesa101 | Production | MLOps & Data Infrastructure |
| [Gojek](https://www.gojek.io/) | @pradithya | Production | Machine Learning Platform |
| Fossil | @duyet | Production | Data Platform |
| Carrefour | @AliGouta | Production | Data Platform |
| Scaling Smart | @tarek-izemrane | Evaluation | Data Platform |
| [Tongdun](https://www.tongdun.net/) | @lomoJG | Production | AI/ML & Analytics |
| [Totvs Labs](https://www.totvslabs.com) | @luizm | Production | Data Platform |
| [DiDi](https://www.didiglobal.com) | @Run-Lin | Evaluation | Data Infrastructure |

==> spark-operator-chart-1.1.7.tar.gz: spark-operator/docs/who-is-using.md <==
## Who Is Using the Kubernetes Operator for Apache Spark?

| Organization | Contact (GitHub User Name) | Environment | Description of Use |
| ------------- | ------------- | ------------- | ------------- |
| [Caicloud](https://intl.caicloud.io/) | @gaocegege | Production | Cloud-Native AI Platform |
| Microsoft (MileIQ) | @dharmeshkakadia | Production | AI & Analytics |
| Lightbend | @yuchaoran2011 | Production | Data Infrastructure & Operations |
| StackTome | @emiliauskas-fuzzy | Production | Data pipelines |
| Salesforce | @khogeland | Production | Data transformation |
| Bringg | @EladDolev | Production | ML & Analytics Data Platform |
| [Siigo](https://www.siigo.com) | @Juandavi1 | Production | Data Migrations & Analytics Data Platform |
| CERN|@mrow4a| Evaluation | Data Mining & Analytics |
| Lyft |@kumare3| Evaluation | ML & Data Infrastructure |
| MapR Technologies |@sarjeet2013| Evaluation | ML/AI & Analytics Data Platform |
| Uber| @chenqin| Evaluation| Spark / ML |
| HashmapInc| @prem0132 | Evaluation | Analytics Data Platform |
| Tencent | @runzhliu | Evaluation | ML Analytics Platform |
| Exacaster | @minutis | Evaluation | Data pipelines |
| Riskified | @henbh | Evaluation | Analytics Data Platform |
| CloudZone | @iftachsc | Evaluation | Big Data Analytics Consultancy |
| Cyren | @avnerl | Evaluation | Data pipelines |
| Shell (Agile Hub) | @TomLous | Production | Data pipelines |
| Nielsen Identity Engine | @roitvt | Evaluation | Data pipelines |
| [Data Mechanics](https://www.datamechanics.co)  | @jrj-d | Production | Managed Spark Platform |
| [PUBG](https://careers.pubg.com/#/en/) | @jacobhjkim | Production | ML & Data Infrastructure |
| [Beeline](https://beeline.ru) | @spestua | Evaluation | ML & Data Infrastructure |
| [Stitch Fix](https://multithreaded.stitchfix.com/) | @nssalian | Evaluation | Data pipelines |
| [Typeform](https://typeform.com/) | @afranzi | Production | Data & ML pipelines |
| incrmntal(https://incrmntal.com/) | @scravy | Production | ML & Data Infrastructure |
| [CloudPhysics](https://www.cloudphysics.com) | @jkleckner | Production | ML/AI & Analytics |
| [MongoDB](https://www.mongodb.com) | @chickenpopcorn | Production | Data Infrastructure |
| [MavenCode](https://www.mavencode.com) | @charlesa101 | Production | MLOps & Data Infrastructure |
| [Gojek](https://www.gojek.io/) | @pradithya | Production | Machine Learning Platform |
| Fossil | @duyet | Production | Data Platform |
| Carrefour | @AliGouta | Production | Data Platform |
| Scaling Smart | @tarek-izemrane | Evaluation | Data Platform |
| [Tongdun](https://www.tongdun.net/) | @lomoJG | Production | AI/ML & Analytics |
| [Totvs Labs](https://www.totvslabs.com) | @luizm | Production | Data Platform |
| [DiDi](https://www.didiglobal.com) | @Run-Lin | Evaluation | Data Infrastructure |
